@@ -15,12 +15,13 @@ use parent qw(Exporter);
 
 use File::Which qw(which);
 use IO::File;
+use IPC::Run3 qw(run3);
 use XSLoader;
 
 our @EXPORT    = qw();
 our @EXPORT_OK = qw(load getloadavg proc_loadavg uptime);
 
-our $VERSION = '0.23'; # TRIAL
+our $VERSION = '0.24'; # TRIAL
 
 XSLoader::load 'Sys::CpuLoad', $VERSION;
 
@@ -39,24 +40,25 @@ sub proc_loadavg {
         }
     }
 
-    return undef;    ## no critic (ProhibitExplicitReturnUndef)
+    return undef;
 }
 
-my $uptime;
+our $UPTIME;
 
 sub uptime {
     local %ENV = %ENV;
     $ENV{'LC_NUMERIC'} = 'POSIX'; # ensure that decimal separator is a dot
 
-    $uptime ||= which("uptime") or
-        return undef; ## no critic (ProhibitExplicitReturnUndef)
+    $UPTIME ||= which("uptime") or
+        return undef;
 
-    my $line = `$uptime`;
-    if ( $line =~ /(\d+\.\d+)\s*,?\s+(\d+\.\d+)\s*,?\s+(\d+\.\d+)\s*$/ )
+    run3($UPTIME, \undef, \my $line);
+    return undef if $? || !defined($line);
+    if ( $line =~ /(\d+\.\d+)\s*,?\s+(\d+\.\d+)\s*,?\s+(\d+\.\d+)\s*$/m )
     {
         return ( $1, $2, $3 );
     }
-    return undef; ## no critic (ProhibitExplicitReturnUndef)
+    return undef;
 }
 
 sub BEGIN {
@@ -94,7 +96,7 @@ Sys::CpuLoad - retrieve system load averages
 
 =head1 VERSION
 
-version 0.23
+version 0.24
 
 =head1 SYNOPSIS
 
@@ -148,10 +150,22 @@ Added in v0.22.
 
 Parse the output of uptime.
 
-If the output cannot be parsed, it will return C<undef>.
+If the L<uptime> executable cannot be found, or the output cannot be
+parsed, it will return C<undef>.
 
 Added in v0.22.
 
+As of v0.24, you can override the executable path by setting
+C<$Sys::CpuLoad::UPTIME>, e.g.
+
+  use Sys::CpuLoad 'uptime';
+
+  no warnings 'once';
+
+  $Sys::CpuLoad::UPTIME = '/usr/bin/w';
+
+  @load = uptime();
+
 =head1 SEE ALSO
 
 L<Sys::CpuLoadX>
